@@ -1,28 +1,22 @@
 import subprocess
 
-def executeRunner(args):
+def executeRunner(arguments, delete, rename, chmod, data):
   """Start the instance configure. this may run a python script, move or/and rename
   file or directory when dondition is filled. the condition may be when file exist or when an entry
   exist into database.
   """
-  arguments, delete, rename, chmod, data = args
-  if delete != []:
+  if delete:
     print "Calling lampconfigure with 'delete' arguments"
-    result = subprocess.Popen(arguments + delete)
-    result.wait()
-  if rename != []:
+    subprocess.call(arguments + delete)
+  if rename:
     for parameters in rename:
       print "Calling lampconfigure with 'rename' arguments"
-      result = subprocess.Popen(arguments + parameters)
-      result.wait()
-  if chmod != []:
+      subprocess.call(arguments + parameters)
+  if chmod:
     print "Calling lampconfigure with 'chmod' arguments"
-    result = subprocess.Popen(arguments + chmod)
-    result.wait()
-  if data != []:
+    subprocess.call(arguments + chmod)
+  if data:
     print "Calling lampconfigure with 'run' arguments"
     print arguments + data
-    result = subprocess.Popen(arguments + data)
-    result.wait()
-    return
+    subprocess.call(arguments + data)
 
